@@ -30,12 +30,6 @@ BALL_MAX_SPEED = 15
 POINTS_TO_WIN = 10
 TEXT_OFFSET = 16
 
-player1 = None
-player2 = None
-hud_sprite = None
-bounce_sound = None
-bounce_wall_sound = None
-score_sound = None
 game_in_progress = True
 
 
@@ -58,7 +52,8 @@ class Game(sge.Game):
             self.fps_time = 0
             self.fps_frames = 0
 
-        self.project_text("hud", self.fps_text, 8, 8, color=sge.Color("gray"))
+        self.project_text(hud_font, self.fps_text, 8, 8,
+                          color=sge.Color("gray"))
 
     def event_key_press(self, key, char):
         global game_in_progress
@@ -112,7 +107,7 @@ class Player(sge.Object):
             self.hit_direction = -1
 
         y = sge.game.height / 2
-        super(Player, self).__init__(x, y, sprite="paddle",
+        super(Player, self).__init__(x, y, sprite=paddle_sprite,
                                      checks_collisions=False)
 
     def event_create(self):
@@ -152,7 +147,7 @@ class Ball(sge.Object):
     def __init__(self):
         x = sge.game.width / 2
         y = sge.game.height / 2
-        super(Ball, self).__init__(x, y, sprite="ball")
+        super(Ball, self).__init__(x, y, sprite=ball_sprite)
 
     def event_create(self):
         self.serve()
@@ -214,11 +209,11 @@ class Ball(sge.Object):
             x = hud_sprite.width / 2
             p1text = "WIN" if player1.score > player2.score else "LOSE"
             p2text = "WIN" if player2.score > player1.score else "LOSE"
-            hud_sprite.draw_text("hud", p1text, x - TEXT_OFFSET, TEXT_OFFSET,
-                                 color=sge.Color("white"),
+            hud_sprite.draw_text(hud_font, p1text, x - TEXT_OFFSET,
+                                 TEXT_OFFSET, color=sge.Color("white"),
                                  halign=sge.ALIGN_RIGHT, valign=sge.ALIGN_TOP)
-            hud_sprite.draw_text("hud", p2text, x + TEXT_OFFSET, TEXT_OFFSET,
-                                 color=sge.Color("white"),
+            hud_sprite.draw_text(hud_font, p2text, x + TEXT_OFFSET,
+                                 TEXT_OFFSET, color=sge.Color("white"),
                                  halign=sge.ALIGN_LEFT, valign=sge.ALIGN_TOP)
             game_in_progress = False
 
@@ -227,60 +222,47 @@ def refresh_hud():
     # This fixes the HUD sprite so that it displays the correct score.
     hud_sprite.draw_clear()
     x = hud_sprite.width / 2
-    hud_sprite.draw_text("hud", str(player1.score), x - TEXT_OFFSET,
+    hud_sprite.draw_text(hud_font, str(player1.score), x - TEXT_OFFSET,
                          TEXT_OFFSET, color=sge.Color("white"),
                          halign=sge.ALIGN_RIGHT, valign=sge.ALIGN_TOP)
-    hud_sprite.draw_text("hud", str(player2.score), x + TEXT_OFFSET,
+    hud_sprite.draw_text(hud_font, str(player2.score), x + TEXT_OFFSET,
                          TEXT_OFFSET, color=sge.Color("white"),
                          halign=sge.ALIGN_LEFT, valign=sge.ALIGN_TOP)
 
 
-def main():
-    global hud_sprite
-    global bounce_sound
-    global bounce_wall_sound
-    global score_sound
-    global player1
-    global player2
+# Create Game object
+Game(width=640, height=480, fps=120, window_text="Pong")
 
-    # Create Game object
-    Game(width=640, height=480, fps=120, window_text="Pong")
+# Load sprites
+paddle_sprite = sge.Sprite(width=8, height=48, origin_x=4, origin_y=24)
+ball_sprite = sge.Sprite(width=8, height=8, origin_x=4, origin_y=4)
+paddle_sprite.draw_rectangle(0, 0, paddle_sprite.width, paddle_sprite.height,
+                             fill=sge.Color("white"))
+ball_sprite.draw_rectangle(0, 0, ball_sprite.width, ball_sprite.height,
+                           fill=sge.Color("white"))
+hud_sprite = sge.Sprite(width=320, height=120, origin_x=160, origin_y=0)
 
-    # Load sprites
-    paddle_sprite = sge.Sprite(ID="paddle", width=8, height=48, origin_x=4,
-                               origin_y=24)
-    ball_sprite = sge.Sprite(ID="ball", width=8, height=8, origin_x=4,
-                             origin_y=4)
-    paddle_sprite.draw_rectangle(0, 0, paddle_sprite.width,
-                                 paddle_sprite.height, fill=sge.Color("white"))
-    ball_sprite.draw_rectangle(0, 0, ball_sprite.width, ball_sprite.height,
-                               fill=sge.Color("white"))
-    hud_sprite = sge.Sprite(width=320, height=120, origin_x=160, origin_y=0)
+# Load backgrounds
+layers = [sge.BackgroundLayer(paddle_sprite, sge.game.width / 2, 0, -10000,
+                              xrepeat=False)]
+background = sge.Background(layers, sge.Color("black"))
 
-    # Load backgrounds
-    layers = [sge.BackgroundLayer("paddle", sge.game.width / 2, 0, -10000,
-                                  xrepeat=False)]
-    background = sge.Background(layers, sge.Color("black"))
+# Load fonts
+hud_font = sge.Font("Droid Sans Mono", size=48)
 
-    # Load fonts
-    sge.Font("Droid Sans Mono", ID="hud", size=48)
+# Load sounds
+bounce_sound = sge.Sound('bounce.wav')
+bounce_wall_sound = sge.Sound('bounce_wall.wav')
+score_sound = sge.Sound('score.wav')
 
-    # Load sounds
-    bounce_sound = sge.Sound('bounce.wav')
-    bounce_wall_sound = sge.Sound('bounce_wall.wav')
-    score_sound = sge.Sound('score.wav')
+# Create objects
+player1 = Player(1)
+player2 = Player(2)
+ball = Ball()
 
-    # Create objects
-    player1 = Player(1)
-    player2 = Player(2)
-    ball = Ball()
-    objects = [player1, player2, ball]
-
-    # Create rooms
-    sge.Room(objects, background=background)
-
-    sge.game.start()
+# Create rooms
+sge.game.start_room = sge.Room([player1, player2, ball], background=background)
 
 
 if __name__ == '__main__':
-    main()
+    sge.game.start()
