@@ -21,8 +21,7 @@ import sge
 
 class Game(object):
 
-    """Class which handles the game.
-
+    """
     This class handles most parts of the game which operate on a global
     scale, such as global game events.  Before anything else is done
     with the SGE, an object either of this class or of a class derived
@@ -31,8 +30,10 @@ class Game(object):
     When an object of this class is created, it is automatically
     assigned to :data:`sge.game`.
 
-    Note: Do not create multiple :class:`sge.Game` objects.  Doing so
-    may cause errors.
+    .. note::
+
+       Do not create multiple :class:`sge.Game` objects.  Doing so is
+       unsupported and may cause errors.
 
     .. attribute:: width
 
@@ -111,6 +112,14 @@ class Game(object):
        to :const:`False` will improve performence if collision events
        are not needed.
 
+    .. attribute:: alarms
+
+       A dictionary containing the global alarms of the game.  Each
+       value decreases by 1 each frame (adjusted for delta timing if it
+       is enabled).  When a value is at or below 0,
+       :meth:`sge.Game.event_alarm` is executed with ``alarm_id`` set to
+       the respective key, and the item is deleted from this dictionary.
+
     .. attribute:: input_events
 
        A list containing all input event objects which have not yet been
@@ -123,52 +132,11 @@ class Game(object):
           :meth:`list.pop`.  Otherwise, the event will be handled more
           than once, which is usually not what you want.
 
-    .. attribute:: registered_classes
+    .. attribute:: start_room
 
-       A list containing all classes which have been registered with
-       :meth:`sge.Game.register_class`.  (Read-only)
-
-    .. attribute:: sprites
-
-       A dictionary containing all loaded sprites, indexed by the
-       sprites' :attr:`sge.Sprite.id` attributes.  (Read-only)
-
-    .. attribute:: background_layers
-
-       A dictionary containing all loaded background layers, indexed by
-       the layers' :attr:`sge.BackgroundLayer.id` attributes.
-       (Read-only)
-
-    .. attribute:: backgrounds
-
-       A dictionary containing all loaded backgrounds, indexed by the
-       backgrounds' :attr:`sge.Background.id` attributes.  (Read-only)
-
-    .. attribute:: fonts
-
-       A dictionary containing all loaded fonts, indexed by the fonts'
-       :attr:`sge.Font.id` attributes.  (Read-only)
-
-    .. attribute:: sounds
-
-       A dictionary containing all loaded sounds, indexed by the sounds'
-       :attr:`sge.Sound.id` attributes.  (Read-only)
-
-    .. attribute:: music
-
-       A dictionary containing all loaded music, indexed by the music
-       objects' :attr:`sge.Music.id` attributes.  (Read-only)
-
-    .. attribute:: objects
-
-       A dictionary containing all :class:`sge.Object` objects in
-       the game, indexed by the objects' :attr:`sge.Object.id`
-       attributes.  (Read-only)
-
-    .. attribute:: rooms
-
-       A list containing all rooms in order of their creation.
-       (Read-only)
+       The room which becomes active when the game first starts and when
+       it restarts.  Must be set exactly once, before the game first
+       starts, and should not be set again afterwards.
 
     .. attribute:: current_room
 
@@ -177,12 +145,13 @@ class Game(object):
     .. attribute:: mouse
 
        A :class:`sge.Object` object which represents the mouse
-       cursor.  Its :attr:`sge.Object.id` attribute is ``"mouse"``
-       and its bounding box is a one-pixel square.
+       cursor.  Its bounding box is a one-pixel square.  It is
+       automatically added to every room's default list of objects.
 
        Some of this object's attributes control properties of the mouse.
        See the documentation for :mod:`sge.mouse` for more information.
 
+       (Read-only)
     """
 
     def __init__(self, width=640, height=480, fullscreen=False, scale=None,
@@ -190,24 +159,21 @@ class Game(object):
                  delta=False, delta_min=15, grab_input=False,
                  window_text=None, window_icon=None,
                  collision_events_enabled=True):
-        """Constructor method.
-
+        """
         Arguments set the respective initial attributes of the game.
         See the documentation for :class:`sge.Game` for more
         information.
 
         The created :class:`sge.Game` object is automatically assigned
         to :data:`sge.game`.
-
         """
         # TODO
 
     def start(self):
-        """Start the game at the first room.
-
-        Can be called in the middle of a game to start the game over.
-        If you do this, everything will be reset to its original state.
-
+        """
+        Start the game at the first room.  Can be called in the middle
+        of a game to start the game over.  If you do this, everything
+        will be reset to its original state.
         """
         # TODO
 
@@ -216,7 +182,8 @@ class Game(object):
         # TODO
 
     def pause(self, sprite=None):
-        """Pause the game.
+        """
+        Pause the game.
 
         Arguments:
 
@@ -229,7 +196,6 @@ class Game(object):
         ``event_paused_`` instead of ``event_`` are executed.  Note that
         not all events have these alternative "paused" events associated
         with them.
-
         """
         # TODO
 
@@ -238,7 +204,8 @@ class Game(object):
         # TODO
 
     def pump_input(self):
-        """Cause the SGE to recieve input from the OS.
+        """
+        Cause the SGE to recieve input from the OS.
 
         This method needs to be called periodically for the SGE to
         recieve events from the OS, such as key presses and mouse
@@ -253,12 +220,12 @@ class Game(object):
         called automatically in each frame of the SGE's main loop.  You
         only need to use this function directly if you take control away
         from the SGE's main loop, e.g. to create your own loop.
-
         """
         # TODO
 
     def regulate_speed(self, fps=None):
-        """Regulate the SGE's running speed and return the time passed.
+        """
+        Regulate the SGE's running speed and return the time passed.
 
         Arguments:
 
@@ -274,12 +241,12 @@ class Game(object):
         called automatically in each frame of the SGE's main loop.  You
         only need to use this function directly if you want to create
         your own loop.
-
         """
         # TODO
 
     def refresh(self):
-        """Refresh the screen.
+        """
+        Refresh the screen.
 
         This method needs to be called for changes to the screen to be
         seen by the user.  It should be called every frame.
@@ -288,52 +255,12 @@ class Game(object):
         called automatically in each frame of the SGE's main loop.  You
         only need to use this function directly if you take control away
         from the SGE's main loop, e.g. to create your own loop.
-
-        """
-        # TODO
-
-    def register_class(self, cls):
-        """Register a class with the SGE.
-
-        Registered classes can be used to index objects by, e.g. for
-        :attr:`sge.Room.objects_by_class`.  A list of all currently
-        registered classes can be found in :attr:`registered_classes`.
-
-        """
-        # TODO
-
-    def set_alarm(self, alarm_id, value):
-        """Set an alarm.
-
-        Arguments:
-
-        - ``alarm_id`` -- The unique identifier of the alarm to set.
-          Any value can be used as a unique identifier for an alarm.
-        - ``value`` -- The value to set the alarm to.  Set to
-          :const:`None` to disable the alarm.
-
-        After this method is called, ``value`` will reduce by 1 each
-        frame (adjusted for delta timing if it is enabled) until it
-        reaches 0, at which point :meth:`sge.Game.event_alarm` will be
-        executed with ``alarm_id``.
-
-        """
-        # TODO
-
-    def get_alarm(self, alarm_id):
-        """Return the value of an alarm.
-
-        Arguments:
-
-        - ``alarm_id`` -- The unique identifier of the alarm to check.
-
-        If the alarm has not been set, :const:`None` will be returned.
-
         """
         # TODO
 
     def project_dot(self, x, y, color):
-        """Project a single-pixel dot onto the game window.
+        """
+        Project a single-pixel dot onto the game window.
 
         Arguments:
 
@@ -344,13 +271,13 @@ class Game(object):
 
         See the documentation for :meth:`sge.Sprite.draw_dot` for more
         information.
-
         """
         # TODO
 
     def project_line(self, x1, y1, x2, y2, color, thickness=1,
                      anti_alias=False):
-        """Project a line segment onto the game window.
+        """
+        Project a line segment onto the game window.
 
         Arguments:
 
@@ -365,13 +292,13 @@ class Game(object):
 
         See the documentation for :meth:`sge.Sprite.draw_line` for more
         information.
-
         """
         # TODO
 
     def project_rectangle(self, x, y, width, height, fill=None, outline=None,
                           outline_thickness=1):
-        """Project a rectangle onto the game window.
+        """
+        Project a rectangle onto the game window.
 
         Arguments:
 
@@ -382,13 +309,13 @@ class Game(object):
 
         See the documentation for :meth:`sge.Sprite.draw_rectangle` for
         more information.
-
         """
         # TODO
 
     def project_ellipse(self, x, y, width, height, fill=None, outline=None,
                         outline_thickness=1, anti_alias=False):
-        """Project an ellipse onto the game window.
+        """
+        Project an ellipse onto the game window.
 
         Arguments:
 
@@ -404,13 +331,13 @@ class Game(object):
 
         See the documentation for :meth:`sge.Sprite.draw_ellipse` for
         more information.
-
         """
         # TODO
 
     def project_circle(self, x, y, radius, fill=None, outline=None,
                        outline_thickness=1, anti_alias=False):
-        """Project a circle onto the game window.
+        """
+        Project a circle onto the game window.
 
         Arguments:
 
@@ -421,12 +348,29 @@ class Game(object):
 
         See the documentation for :meth:`sge.Sprite.draw_circle` for
         more information.
+        """
+        # TODO
 
+    def project_polygon(self, points, fill=None, outline=None,
+                        outline_thickness=1, anti_alias=False):
+        """
+        Draw a polygon on the sprite.
+
+        Arguments:
+
+        - ``points`` -- A list of points relative to the room to
+          position each of the polygon's angles.  Each point should be a
+          tuple in the form ``(x, y)``, where x is the horizontal
+          location and y is the vertical location.
+
+        See the documentation for :meth:`sge.Sprite.draw_polygon` for
+        more information.
         """
         # TODO
 
     def project_sprite(self, sprite, image, x, y, blend_mode=None):
-        """Project a sprite onto the game window.
+        """
+        Project a sprite onto the game window.
 
         Arguments:
 
@@ -437,14 +381,14 @@ class Game(object):
 
         See the documentation for :meth:`sge.Sprite.draw_sprite` for
         more information.
-
         """
         # TODO
 
     def project_text(self, font, text, x, y, width=None, height=None,
                     color=sge.Color("black"), halign=sge.ALIGN_LEFT,
                     valign=sge.ALIGN_TOP, anti_alias=True):
-        """Project text onto the game window.
+        """
+        Project text onto the game window.
 
         Arguments:
 
@@ -455,32 +399,26 @@ class Game(object):
 
         See the documentation for :meth:`sge.Sprite.draw_text` for more
         information.
-
         """
         # TODO
 
     def event_game_start(self):
-        """Game start event.
-
+        """
         Called when the game starts.  This is only called once (it is
-        not called again when the game restarts) and it is always the
+        not called again when the game restarts), and it is always the
         very first event method called.
-
         """
         pass
 
     def event_game_end(self):
-        """Game end event.
-
-        Called when the game ends.  It is only called once and it is
+        """
+        Called when the game ends.  This is only called once, and it is
         always the very last event method called.
-
         """
         pass
 
     def event_step(self, time_passed, delta_mult):
-        """Global step event.
-
+        """
         Called once each frame.
 
         Arguments:
@@ -490,343 +428,268 @@ class Game(object):
         - ``delta_mult`` -- What speed and movement should be multiplied
           by this frame due to delta timing.  If :attr:`delta` is
           :const:`False`, this is always ``1``.
-
         """
         pass
 
     def event_alarm(self, alarm_id):
-        """Alarm event.
-
+        """
         Called when the value of an alarm reaches 0.
 
-        Arguments:
-
-        - ``alarm_id`` -- The unique identifier of the alarm which was
-          set off.
-
+        See the documentation for :meth:`sge.Game.alarms` for more
+        information.
         """
         pass
 
     def event_key_press(self, key, char):
-        """Key press event.
-
+        """
         See the documentation for :class:`sge.input.KeyPress` for more
         information.
-
         """
         pass
 
     def event_key_release(self, key):
-        """Key release event.
-
+        """
         See the documentation for :class:`sge.input.KeyRelease` for more
         information.
-
         """
         pass
 
     def event_mouse_move(self, x, y):
-        """Mouse move event.
-
+        """
         See the documentation for :class:`sge.input.MouseMove` for more
         information.
-
         """
         pass
 
     def event_mouse_button_press(self, button):
-        """Mouse button press event.
-
+        """
         See the documentation for :class:`sge.input.MouseButtonPress`
         for more information.
-
         """
         pass
 
     def event_mouse_button_release(self, button):
-        """Mouse button release event.
-
+        """
         See the documentation for :class:`sge.input.MouseButtonRelease`
         for more information.
-
         """
         pass
 
     def event_joystick_axis_move(self, js_name, js_id, axis, value):
-        """Joystick axis move event.
-
+        """
         See the documentation for :class:`sge.input.JoystickAxisMove`
         for more information.
-
         """
         pass
 
     def event_joystick_hat_move(self, js_name, js_id, hat, x, y):
-        """Joystick hat move event.
-
+        """
         See the documentation for :class:`sge.input.JoystickHatMove`
         for more information.
-
         """
         pass
 
     def event_joystick_trackball_move(self, js_name, js_id, ball, x, y):
-        """Joystick trackball move event.
-
+        """
         See the documentation for
         :class:`sge.input.JoystickTrackballMove` for more information.
-
         """
         pass
 
     def event_joystick_button_press(self, js_name, js_id, button):
-        """Joystick button press event.
-
+        """
         See the documentation for :class:`sge.input.JoystickButtonPress`
         for more information.
-
         """
         pass
 
     def event_joystick_button_release(self, js_name, js_id, button):
-        """Joystick button release event.
-
+        """
         See the documentation for
         :class:`sge.input.JoystickButtonRelease` for more information.
-
         """
         pass
 
     def event_gain_keyboard_focus(self):
-        """Gain keyboard focus event.
-
+        """
         See the documentation for :class:`sge.input.KeyboardFocusGain`
         for more information.
-
         """
         pass
 
     def event_lose_keyboard_focus(self):
-        """Lose keyboard focus event.
-
+        """
         See the documentation for :class:`sge.input.KeyboardFocusLose`
         for more information.
-
         """
         pass
 
     def event_gain_mouse_focus(self):
-        """Gain mouse focus event.
-
+        """
         See the documentation for :class:`sge.input.MouseFocusGain` for
         more information.
-
         """
         pass
 
     def event_lose_mouse_focus(self):
-        """Lose mouse focus event.
-
+        """
         See the documentation for :class:`sge.input.MouseFocusLose` for
         more information.
-
         """
         pass
 
     def event_close(self):
-        """Close event.
-
-        This is always called after any :meth:`sge.Room.event_close`
-        occurring at the same time.
-
+        """
         See the documentation for :class:`sge.input.QuitRequest` for
         more information.
 
+        This is always called after any :meth:`sge.Room.event_close`
+        occurring at the same time.
         """
         pass
 
     def event_mouse_collision(self, other):
-        """Default mouse collision event.
-
+        """
         Proxy for :meth:`sge.game.mouse.event_collision`.  See the
         documentation for :meth:`sge.Object.event_collision` for
         more information.
-
         """
         pass
 
     def event_mouse_collision_left(self, other):
-        """Left mouse collision event.
-
+        """
         Proxy for :meth:`sge.game.mouse.event_collision_left`.  See the
         documentation for :meth:`sge.Object.event_collision_left`
         for more information.
-
         """
         self.event_mouse_collision(other)
 
     def event_mouse_collision_right(self, other):
-        """Right mouse collision event.
-
+        """
         Proxy for :meth:`sge.game.mouse.event_collision_right`.  See the
         documentation for :meth:`sge.Object.event_collision_right`
         for more information.
-
         """
         self.event_mouse_collision(other)
 
     def event_mouse_collision_top(self, other):
-        """Top mouse collision event.
-
+        """
         Proxy for :meth:`sge.game.mouse.event_collision_top`.  See the
         documentation for :meth:`sge.Object.event_collision_top`
         for more information.
-
         """
         self.event_mouse_collision(other)
 
     def event_mouse_collision_bottom(self, other):
-        """Bottom mouse collision event.
-
+        """
         Proxy for :meth:`sge.game.mouse.event_collision_bottom`.  See
         the documentation for
         :meth:`sge.Object.event_collision_bottom` for more
         information.
-
         """
         self.event_mouse_collision(other)
 
     def event_paused_key_press(self, key, char):
-        """Key press event when paused.
-
+        """
         See the documentation for :class:`sge.input.KeyPress` for more
         information.
-
         """
         pass
 
     def event_paused_key_release(self, key):
-        """Key release event when paused.
-
+        """
         See the documentation for :class:`sge.input.KeyRelease` for more
         information.
-
         """
         pass
 
     def event_paused_mouse_move(self, x, y):
-        """Mouse move event when paused.
-
+        """
         See the documentation for :class:`sge.input.MouseMove` for more
         information.
-
         """
         pass
 
     def event_paused_mouse_button_press(self, button):
-        """Mouse button press event when paused.
-
+        """
         See the documentation for :class:`sge.input.MouseButtonPress`
         for more information.
-
         """
         pass
 
     def event_paused_mouse_button_release(self, button):
-        """Mouse button release event when paused.
-
+        """
         See the documentation for :class:`sge.input.MouseButtonRelease`
         for more information.
-
         """
         pass
 
     def event_paused_joystick_axis_move(self, js_name, js_id, axis, value):
-        """Joystick axis move event when paused.
-
+        """
         See the documentation for :class:`sge.input.JoystickAxisMove`
         for more information.
-
         """
         pass
 
     def event_paused_joystick_hat_move(self, js_name, js_id, hat, x, y):
-        """Joystick hat move event when paused.
-
+        """
         See the documentation for :class:`sge.input.JoystickHatMove` for
         more information.
-
         """
         pass
 
     def event_paused_joystick_trackball_move(self, js_name, js_id, ball, x, y):
-        """Joystick trackball move event when paused.
-
+        """
         See the documentation for
         :class:`sge.input.JoystickTrackballMove` for more information.
-
         """
         pass
 
     def event_paused_joystick_button_press(self, js_name, js_id, button):
-        """Joystick button press event when paused.
-
+        """
         See the documentation for :class:`sge.input.JoystickButtonPress`
         for more information.
-
         """
         pass
 
     def event_paused_joystick_button_release(self, js_name, js_id, button):
-        """Joystick button release event when paused.
-
+        """
         See the documentation for
         :class:`sge.input.JoystickButtonRelease` for more information.
-
         """
         pass
 
     def event_paused_gain_keyboard_focus(self):
-        """Gain keyboard focus event when paused.
-
+        """
         See the documentation for :class:`sge.input.KeyboardFocusGain`
         for more information.
-
         """
         pass
 
     def event_paused_lose_keyboard_focus(self):
-        """Lose keyboard focus event when paused.
-
+        """
         See the documentation for :class:`sge.input.KeyboardFocusLose`
         for more information.
-
         """
         pass
 
     def event_paused_gain_mouse_focus(self):
-        """Gain mouse focus event when paused.
-
+        """
         See the documentation for :class:`sge.input.MouseFocusGain` for
         more information.
-
         """
         pass
 
     def event_paused_lose_mouse_focus(self):
-        """Lose mouse focus event when paused.
-
+        """
         See the documentation for :class:`sge.input.MouseFocusLose` for
         more information.
-
         """
         pass
 
     def event_paused_close(self):
-        """Close event when paused.
-
+        """
         See the documentation for :meth:`sge.Game.event_close` for more
         information.
-
         """
         pass
