@@ -14,15 +14,14 @@
 # above as well as the notices contained in other source files with your
 # own copyright notice.  Recommended free  licenses are  the GNU General
 # Public License, GNU Lesser General Public License, Expat License, or
-# Apache License 2.0.
+# Apache License.
 
-__all__ = ['Sound']
+import sge
 
 
 class Sound(object):
 
-    """Sound handling class.
-
+    """
     This class stores and plays sound effects.  Note that this is
     inefficient for large music files; for those, use :class:`sge.Music`
     instead.
@@ -43,7 +42,7 @@ class Sound(object):
        If a sound is played while this number of the instances of the
        same sound are already playing, one of the already playing sounds
        will be stopped before playing the new instance.  Set to
-       :const:`None` or ``0`` for no limit.
+       :const:`None` for no limit.
 
     .. attribute:: fname
 
@@ -58,11 +57,13 @@ class Sound(object):
 
        The number of instances of this sound playing.  (Read-only)
 
+    .. attribute:: rd
+
+       Reserved dictionary for internal use by the SGE.  (Read-only)
     """
 
-    def __init__(self, fname, ID=None, volume=100, max_play=1):
-        """Constructor method.
-
+    def __init__(self, fname, volume=100, max_play=1):
+        """
         Arguments:
 
         - ``fname`` -- The name of the sound file in one of the paths
@@ -70,21 +71,17 @@ class Sound(object):
           :const:`None`, this object will not actually play any sound.
           If this is neither a valid sound file nor :const:`None`,
           :exc:`IOError` is raised.
-        - ``ID`` -- The value to set :attr:`id` to.  If set to
-          :const:`None`, ``fname`` minus the extension will be used,
-          modified by the SGE if it is already the unique identifier of
-          another sound object.
 
         All other arguments set the respective initial attributes of the
         sound.  See the documentation for :class:`sge.Sound` for more
         information.
-
         """
         # TODO
 
     def play(self, loops=1, volume=100, balance=0, maxtime=None,
              fade_time=None):
-        """Play the sound.
+        """
+        Play the sound.
 
         Arguments:
 
@@ -98,23 +95,22 @@ class Sound(object):
           centered (full volume in both speakers), ``1`` is entirely in
           the right speaker, and ``-1`` is entirely in the left speaker.
         - ``maxtime`` -- The maximum amount of time to play the sound in
-          milliseconds; set to :const:`None` or ``0`` for no limit.
+          milliseconds; set to :const:`None` for no limit.
         - ``fade_time`` -- The time in milliseconds over which to fade
           the sound in; set to :const:`None` or ``0`` to immediately
           play the sound at full volume.
-
         """
         # TODO
 
     def stop(self, fade_time=None):
-        """Stop the sound.
+        """
+        Stop the sound.
 
         Arguments:
 
         - ``fade_time`` -- The time in milliseconds over which to fade
           the sound out before stopping; set to :const:`None` or ``0``
           to immediately stop the sound.
-
         """
         # TODO
 
@@ -126,10 +122,6 @@ class Sound(object):
         """Resume playback of the sound if paused."""
         # TODO
 
-    def destroy(self):
-        """Destroy the sound."""
-        # TODO
-
     @staticmethod
     def stop_all():
         """Stop playback of all sounds."""
