@@ -21,8 +21,7 @@ import sge
 
 class Sprite(object):
 
-    """Class which holds information for images and animations.
-
+    """
     This class stores images and information about how the SGE is to use
     those images.
 
@@ -109,22 +108,19 @@ class Sprite(object):
 
        The name of the sprite given when it was created.  (Read-only)
 
-    .. attribute:: id
-
-       The unique identifier of the sprite.  (Read-only)
-
     .. attribute:: frames
 
        The number of animation frames in the sprite.  (Read-only)
 
+    .. attribute:: rd
+
+       Reserved dictionary for internal use by the SGE.  (Read-only)
     """
 
-    def __init__(self, name=None, ID=None, width=None, height=None,
-                 transparent=True, origin_x=0, origin_y=0, fps=60,
-                 bbox_x=None, bbox_y=None, bbox_width=None,
-                 bbox_height=None):
-        """Constructor method.
-
+    def __init__(self, name=None, width=None, height=None, transparent=True,
+                 origin_x=0, origin_y=0, fps=60, bbox_x=None, bbox_y=None,
+                 bbox_width=None, bbox_height=None):
+        """
         Arguments:
 
         - ``name`` -- The base name of the image files, used to find all
@@ -154,14 +150,9 @@ class Sprite(object):
           If none of the above rules can be used, :exc:`IOError` is
           raised.
 
-        - ``ID`` -- The value to assign :attr:`id` to.  If set to
-          :const:`None`, ``name`` will be used, modified by the SGE if
-          it is already the unique identifier of another sprite.
-
         All other arguments set the respective initial attributes of the
         sprite.  See the documentation for :class:`Sprite` for more
         information.
-
         """
         # TODO
 
@@ -170,29 +161,30 @@ class Sprite(object):
         # TODO
 
     def insert_frame(self, frame):
-        """Insert a new blank frame into the sprite.
+        """
+        Insert a new blank frame into the sprite.
 
         Arguments:
 
         - ``frame`` -- The frame of the sprite to insert the new frame
           in front of, where ``0`` is the first frame.
-
         """
         # TODO
 
     def delete_frame(self, frame):
-        """Delete a frame from the sprite.
+        """
+        Delete a frame from the sprite.
 
         Arguments:
 
         - ``frame`` -- The frame of the sprite to delete, where ``0`` is
           the first frame.
-
         """
         # TODO
 
     def draw_dot(self, x, y, color, frame=None):
-        """Draw a single-pixel dot on the sprite.
+        """
+        Draw a single-pixel dot on the sprite.
 
         Arguments:
 
@@ -205,13 +197,13 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
-
         """
         # TODO
 
     def draw_line(self, x1, y1, x2, y2, color, thickness=1, anti_alias=False,
                   frame=None):
-        """Draw a line segment on the sprite.
+        """
+        Draw a line segment on the sprite.
 
         Arguments:
 
@@ -230,13 +222,13 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
-
         """
         # TODO
 
     def draw_rectangle(self, x, y, width, height, fill=None, outline=None,
                        outline_thickness=1, frame=None):
-        """Draw a rectangle on the sprite.
+        """
+        Draw a rectangle on the sprite.
 
         Arguments:
 
@@ -255,13 +247,13 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
-
         """
         # TODO
 
     def draw_ellipse(self, x, y, width, height, fill=None, outline=None,
                      outline_thickness=1, anti_alias=False, frame=None):
-        """Draw an ellipse on the sprite.
+        """
+        Draw an ellipse on the sprite.
 
         Arguments:
 
@@ -281,13 +273,13 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
-
         """
         # TODO
 
     def draw_circle(self, x, y, radius, fill=None, outline=None,
                     outline_thickness=1, anti_alias=False, frame=None):
-        """Draw a circle on the sprite.
+        """
+        Draw a circle on the sprite.
 
         Arguments:
 
@@ -306,12 +298,36 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
+        """
+        # TODO
 
+    def draw_polygon(self, points, fill=None, outline=None,
+                     outline_thickness=1, anti_alias=False, frame=None):
+        """
+        Draw a polygon on the sprite.
+
+        Arguments:
+
+        - ``points`` -- A list of points relative to the sprite to
+          position each of the polygon's angles.  Each point should be a
+          tuple in the form ``(x, y)``, where x is the horizontal
+          location and y is the vertical location.
+        - ``fill`` -- A :class:`sge.Color` object representing the color
+          of the fill of the polygon.
+        - ``outline`` -- A :class:`sge.Color` object representing the
+          color of the outline of the polygon.
+        - ``outline_thickness`` -- The thickness of the outline of the
+          polygon.
+        - ``anti_alias`` -- Whether or not anti-aliasing should be used.
+        - ``frame`` -- The frame of the sprite to draw on, where ``0``
+          is the first frame; set to :const:`None` to draw on all
+          frames.
         """
         # TODO
 
     def draw_sprite(self, sprite, image, x, y, frame=None, blend_mode=None):
-        """Draw another sprite on the sprite.
+        """
+        Draw another sprite on the sprite.
 
         Arguments:
 
@@ -343,14 +359,14 @@ class Sprite(object):
           - :data:`sge.BLEND_RGB_MAXIMUM`
 
           :const:`None` is treated as :data:`sge.BLEND_NORMAL`.
-
         """
         # TODO
 
     def draw_text(self, font, text, x, y, width=None, height=None,
                   color=sge.Color("black"), halign=sge.ALIGN_LEFT,
                   valign=sge.ALIGN_TOP, anti_alias=True, frame=None):
-        """Draw text on the sprite.
+        """
+        Draw text on the sprite.
 
         Arguments:
 
@@ -409,12 +425,12 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to draw on, where ``0``
           is the first frame; set to :const:`None` to draw on all
           frames.
-
         """
         # TODO
 
     def draw_erase(self, x, y, width, height, frame=None):
-        """Erase part of the sprite.
+        """
+        Erase part of the sprite.
 
         Arguments:
 
@@ -427,23 +443,23 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to erase from, where
           ``0`` is the first frame; set to :const:`None` to erase from
           all frames.
-
         """
         # TODO
 
     def draw_clear(self, frame=None):
-        """Erase everything from the sprite.
+        """
+        Erase everything from the sprite.
 
         Arguments:
 
         - ``frame`` -- The frame of the sprite to clear, where ``0`` is
           the first frame; set to :const:`None` to clear all frames.
-
         """
         self.draw_erase(0, 0, self.width, self.height, frame)
 
     def draw_lock(self):
-        """Lock the sprite for continuous drawing.
+        """
+        Lock the sprite for continuous drawing.
 
         Use this method to "lock" the sprite for being drawn on several
         times in a row.  What exactly this does depends on the
@@ -464,21 +480,21 @@ class Sprite(object):
            and as severe as crashing the program, depending on the SGE
            implementation.  Always call :meth:`sge.Sprite.draw_unlock`
            immediately after you're done drawing for a while.
-
         """
         # TODO
 
     def draw_unlock(self):
-        """Unlock the sprite.
+        """
+        Unlock the sprite.
 
         Use this method to "unlock" the sprite after it has been
         "locked" for continuous drawing by :meth:`sge.Sprite.draw_lock`.
-
         """
         # TODO
 
     def save(self, fname):
-        """Save the sprite to an image file.
+        """
+        Save the sprite to an image file.
 
         Arguments:
 
@@ -489,28 +505,16 @@ class Sprite(object):
         If the sprite has multiple frames, the image file saved will be
         a horizontal reel of each of the frames from left to right with
         no space in between the frames.
-
-        """
-        # TODO
-
-    def destroy(self):
-        """Destroy the sprite.
-
-        .. note::
-
-           If the sprite is being used, for example, by a
-           :class:`sge.Object` object, it will not be completely
-           destroyed until this use stops.
-
         """
         # TODO
 
     @classmethod
-    def from_tileset(cls, name, ID=None, x=0, y=0, columns=1, rows=1, xsep=0,
-                     ysep=0, width=1, height=1, origin_x=0, origin_y=0,
+    def from_tileset(cls, name, x=0, y=0, columns=1, rows=1, xsep=0, ysep=0,
+                     width=1, height=1, origin_x=0, origin_y=0,
                      transparent=True, fps=0, bbox_x=None, bbox_y=None,
                      bbox_width=None, bbox_height=None):
-        """Return a sprite based on the tiles in a tileset.
+        """
+        Return a sprite based on the tiles in a tileset.
 
         Arguments:
 
@@ -533,14 +537,14 @@ class Sprite(object):
 
         Each tile in the tileset becomes a subimage of the returned
         sprite, ordered first from left to right and then from top to
-        bottom.  The sprite's :attr:`fps` attribute is set to ``0``.
-
+        bottom.
         """
         # TODO
 
     @classmethod
     def from_screenshot(cls, x=0, y=0, width=None, height=None):
-        """Return the current display on the screen as a sprite.
+        """
+        Return the current display on the screen as a sprite.
 
         Arguments:
 
@@ -559,6 +563,5 @@ class Sprite(object):
         a file, the easiest way to do that is::
 
             sge.Sprite.from_screenshot().save("foo.png")
-
         """
         # TODO
