@@ -35,24 +35,6 @@ contribution to a free society.
 SGE Concepts
 ============
 
-Naming Conventions
-------------------
-
-There are many cases where you will want to derive a class from a SGE
-class.  Since there can be multiple implementations of the SGE, it can
-be easy when doing so to overwrite a special variable used by some
-implementations internally, which can be disastrous.  To avoid such
-occasions, implementations are expected to never introduce any attribute
-names which are not explicitly mentioned in the documentation for a
-class unless the new attribute names are preceded by an underscore, as
-in the hypothetical attribute name ``_foo``.  This naming convention
-will protect users of the SGE from unexpected errors provided that they
-do not use such names themselves.
-
-A suggested convention for users of the SGE to use for "private"
-attributes in place of the usual leading underscore  is to precede these
-attributes with ``v_`` or ``p_``.
-
 Events
 ------
 
@@ -270,22 +252,26 @@ Global Variables and Constants
 
    A list of directories where images can be found.  Default is
    ``./data/images``, ``./data/sprites``, or ``./data/backgrounds``,
-   where ``.`` is the program directory.
+   where ``.`` is the program directory.  Directories within the
+   listed directories are not included.
 
 .. data:: sge.font_directories
 
    A list of directories where font files can be found.  Default is
-   ``./data/fonts``, where ``.`` is the program directory.
+   ``./data/fonts``, where ``.`` is the program directory.  Directories
+   within the listed directories are not included.
 
 .. data:: sge.sound_directories
 
    A list of directories where sounds can be found.  Default is
-   ``./data/sounds``, where ``.`` is the program directory.
+   ``./data/sounds``, where ``.`` is the program directory.  Directories
+   within the listed directories are not included.
 
 .. data:: sge.music_directories
 
    A list of directories where music files can be found.  Default is
-   ``./data/music``, where ``.`` is the program directory.
+   ``./data/music``, where ``.`` is the program directory.  Directories
+   within the listed directories are not included.
 
 Information specific to [insert implementation name here]
 =========================================================
@@ -306,7 +292,7 @@ Dependencies
 [insert other info here]
 """
 
-__version__ = "0.13"
+__version__ = "0.14"
 
 import sys
 import os
@@ -414,7 +400,7 @@ from sge.Music import Music
 from sge.Object import Object, Mouse
 from sge.Room import Room
 from sge.View import View
-from sge import collision, input, joystick, keyboard, mouse
+from sge import collision, input, joystick, keyboard, mouse, r
 
 
 __all__ = [
